patch_id create_deponi_20022018


IF NOT EXISTS(SELECT NULL FROM sys.database_principals WHERE name = 'DEPONI_USER' AND type='R')
CREATE ROLE DEPONI_USER ;

create table dbo.deponi (
   deponi_seq_no        numeric(9,0)         not null,
   site_seq_no          numeric(9,0)         not null,
   location             varchar(80)          null,
   establish_date       datetime             null,
   closed_date          datetime             null,
   active               varchar(1)           null default '1',
   report_jup           varchar(1)           null default '0',
   jour_no              varchar(32)          null,
   telephone            varchar(12)          null,
   mobile               varchar(12)          null,
   district2007         varchar(6)           null,
   status_code          varchar(6)           null,
   water_type           varchar(6)           null,
   jup_id               varchar(8)           null,
   message_jup          varchar(255)         null,
   receive_waste        varchar(1)           null default '0',
   closed_before_2001   varchar(1)           null default '0',
   privat_owned         varchar(1)           null default '0',
   public_owned         varchar(1)           null default '0',
   comments             varchar(255)         null,
   dispensation_spec_landfill varchar(1)           null default '0',
   sediment_landfill    varchar(1)           null default '0',
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI primary key (deponi_seq_no))
go

IF NOT EXISTS(SELECT * FROM sys.indexes WHERE Name = 'UIDX_DEPONI_SITE_SEQ_NO')
create unique index UIDX_DEPONI_SITE_SEQ_NO on deponi (
site_seq_no ASC
)
go

grant SELECT,INSERT,DELETE,UPDATE on deponi to DEPONI_USER
go


create table dbo.deponi_analysis_program (
   dap_seq_no           numeric(9,0)         not null,
   deponi_seq_no        numeric(9,0)         not null,
   id                   int                  not null,
   name                 varchar(80)          not null,
   comments             varchar(500)         null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_ANALYSIS_PROGRAM primary key (dap_seq_no)
)
go

IF NOT EXISTS(SELECT * FROM sys.indexes WHERE Name = 'uidx_deponi_analysis_program')
create unique index uidx_deponi_analysis_program on deponi_analysis_program (deponi_seq_no, id)

grant SELECT on deponi_analysis_program to DEPONI_USER
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_analysis_program to SYSMGR
go

create table dbo.deponi_ap_parameter (
   dapp_seq_no          numeric(9,0)         not null,
   dap_seq_no           numeric(9,0)         not null,
   parameter            varchar(6)           not null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_AP_PARAMETER primary key (dapp_seq_no)
)
go

IF NOT EXISTS(SELECT * FROM sys.indexes WHERE Name = 'uidx_deponi_ap_parameter')
create unique index uidx_deponi_ap_parameter on deponi_ap_parameter (
dap_seq_no ASC, parameter Asc
)
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_ap_parameter to DEPONI_USER
go

create table dbo.deponi_deadline_ok (
   dapd_seq_no          numeric(9,0)         not null,
   dapp_seq_no          numeric(9,0)         not null,
   aar                  integer              not null,
   ok                   char(1)              null,
   comments             varchar(max)         null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_DEADLINE_OK primary key (dapd_seq_no, dapp_seq_no, aar)
)
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_deadline_ok to DEPONI_USER
go

create table dbo.deponi_leachate (
   deponi_seq_no        numeric(9,0)         not null,
   year                 integer              not null,
   m3                   integer              not null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_LEACHATE primary key (deponi_seq_no, year)
)
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_leachate to DEPONI_USER
go


create table dbo.deponi_max_value (
   dmv_seq_no           numeric(9,0)         not null,
   dsp_seq_no           numeric(9,0)         not null,
   parameter            varchar(6)           not null,
   unit                 varchar(6)           null,
   from_date            date                 null,
   to_date              date                 null,
   low                  decimal(12,4)        null,
   middle               decimal(12,4)        null,
   high                 decimal(12,4)        null,
   risk                 varchar(1)           null,
   low_ignore           varchar(1)           null,
   middle_ignore        varchar(1)           null,
   high_ignore          varchar(1)           null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_MAX_VALUE primary key (dmv_seq_no)
)
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_max_value to DEPONI_USER
go


create table dbo.deponi_max_value_ok (
   dsp_seq_no           numeric(9,0)         not null,
   parameter            varchar(6)           not null,
   dato                 datetime             not null,
   ok                   char(1)              null,
   comments             varchar(max)         null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_MAX_VALUE_OK primary key (dsp_seq_no, parameter, dato)
)
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_max_value_ok to DEPONI_USER
go


create table dbo.deponi_sampling_place (
   dsp_seq_no           numeric(9,0)         not null,
   filterid             numeric(9,0)         null,
   place_seq_no         numeric(9,0)         null,
   deponi_seq_no        numeric(9,0)         null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_SAMPLING_PLACE primary key (dsp_seq_no)
)
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_sampling_place to DEPONI_USER
go


create table dbo.deponi_sampling_place_ap (
   dspa_seq_no          numeric(9,0)         not null,
   dap_seq_no           numeric(9,0)         not null,
   dsp_seq_no           numeric(9,0)         not null,
   from_date            date                 null,
   to_date              date                 null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_SAMPLING_PLACE_AP primary key (dspa_seq_no)
)
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_sampling_place_ap to DEPONI_USER
go


create table dbo.deponi_sp_ap_deadline (
   dapd_seq_no          numeric(9,0)         not null,
   dspa_seq_no          numeric(9,0)         null,
   from_month           integer              not null,
   to_month             integer              not null,
   number_of_analysis   integer              not null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_SP_AP_DEADLINE primary key (dapd_seq_no)
)
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_sp_ap_deadline to DEPONI_USER
go


create table dbo.deponi_subunit (
   unit_seq_no          numeric(9,0)         not null,
   sub_unit_id          varchar(20)          not null,
   sub_unit_name        varchar(80)          null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_SUBUNIT primary key (unit_seq_no, sub_unit_id)
)
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_subunit to DEPONI_USER
go


create table dbo.deponi_unit (
   unit_seq_no          numeric(9,0)         not null,
   unit_id              varchar(20)          not null,
   unit_name            varchar(80)          null,
   classification       varchar(6)           null,
   deponi_seq_no        numeric(9,0)         not null,
   establish_date       datetime             null,
   approved_date        datetime             null,
   closed_date          datetime             null,
   passive_date         datetime             null,
   description          varchar(500)         null,
   reduced_demands      varchar(1)           null default '0',
   further_reduced_demands varchar(1)           null default '0',
   approved_volume_m3   integer              null,
   approved_quantity_ton integer              null,
   appproved_area_m2    integer              null,
   comments             varchar(Max)         null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_UNIT primary key (unit_seq_no)
)
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_unit to DEPONI_USER
go


create table dbo.deponi_unit_classification (
   classification       varchar(6)           not null,
   classification_name  varchar(60)          not null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_UNIT_CLASSIFICATION primary key (classification)
)
go

grant SELECT on deponi_unit_classification to DEPONI_USER
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_unit_classification to SYSMGR
go


create table dbo.deponi_unit_leachate (
   unit_seq_no          numeric(9,0)         not null,
   year                 integer              not null,
   removed_m3           integer              not null,
   residual_capacity_m3 integer              null,
   residual_capacity_ton integer              null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_UNIT_LEACHATE primary key (unit_seq_no, year)
)
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_unit_leachate to DEPONI_USER
go

create table dbo.deponi_unit_waste_capacity (
   unit_seq_no          numeric(9,0)         not null,
   year                 integer              not null,
   m3                   integer              null,
   ton                  integer              null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_UNIT_WASTE_CAPACITY primary key (unit_seq_no, year)
)
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_unit_waste_capacity to DEPONI_USER
go

create table dbo.deponi_x_boring (
   deponi_seq_no        numeric(9,0)         not null,
   boring_seq_no        numeric(9,0)         not null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_X_BORING primary key (deponi_seq_no, boring_seq_no)
)
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_x_boring to DEPONI_USER
go

IF(OBJECT_ID('FK_DEPONI_SITE', 'F') IS NULL)
alter table deponi
   add constraint FK_DEPONI_SITE foreign key (site_seq_no)
      references site (site_seq_no)
go

IF(OBJECT_ID('FK_DEPONI_ANALYSIS_PROGRAM_DEPONI', 'F') IS NULL)
alter table deponi_analysis_program
   add constraint FK_DEPONI_ANALYSIS_PROGRAM_DEPONI foreign key (deponi_seq_no)
      references deponi (deponi_seq_no)
go

IF(OBJECT_ID('FK_DEPONI_APP_PARAM_DEPONI_ANA_PROGRAM', 'F') IS NULL)
alter table deponi_ap_parameter
   add constraint FK_DEPONI_APP_PARAM_DEPONI_ANA_PROGRAM foreign key (dap_seq_no)
      references deponi_analysis_program (dap_seq_no)
go

IF(OBJECT_ID('FK_DEPONI_AP_PARAM_STD00019', 'F') IS NULL)
alter table deponi_ap_parameter
   add constraint FK_DEPONI_AP_PARAM_STD00019 foreign key (parameter)
      references std00019 (code)
go

IF(OBJECT_ID('FK_DEPONI_SITE', 'F') IS NULL)
alter table deponi_deadline_ok
   add constraint FK_DEPONI_DEAD_DEPONI_SP_AP_DEAD foreign key (dapd_seq_no)
      references deponi_sp_ap_deadline (dapd_seq_no)
         on delete cascade
go

IF(OBJECT_ID('FK_DEPONI_DEAD_DEPONI_SP_AP_DEAD', 'F') IS NULL)
alter table deponi_deadline_ok
   add constraint FK_DEPONI_DEAD_DEPONI_DEAD_OK foreign key (dapp_seq_no)
      references deponi_ap_parameter (dapp_seq_no)
         on delete cascade
go

IF(OBJECT_ID('FK_DEPONI_LEACHATE_DEPONI', 'F') IS NULL)
alter table deponi_leachate
   add constraint FK_DEPONI_LEACHATE_DEPONI foreign key (deponi_seq_no)
      references deponi (deponi_seq_no)
go

IF(OBJECT_ID('FK_DEPONI_MAX_VALUE_GSC_UNIT', 'F') IS NULL)
alter table deponi_max_value
   add constraint FK_DEPONI_MAX_VALUE_GSC_UNIT foreign key (unit)
      references gsc_unit (code)
go

IF(OBJECT_ID('FK_DEPONI_MAX_VALUE_DEP_SAMP_PLAC', 'F') IS NULL)
alter table deponi_max_value
   add constraint FK_DEPONI_MAX_VALUE_DEP_SAMP_PLAC foreign key (dsp_seq_no)
      references deponi_sampling_place (dsp_seq_no)
go

IF(OBJECT_ID('FK_DEPONI_MAX_VALUE_STD00019', 'F') IS NULL)
alter table deponi_max_value
   add constraint FK_DEPONI_MAX_VALUE_STD00019 foreign key (parameter)
      references std00019 (code)
go

IF(OBJECT_ID('FK_DEPONI_MAX_VALUE_DEP_SAMPL_PLACE', 'F') IS NULL)
alter table deponi_max_value_ok
   add constraint FK_DEPONI_MAX_VALUE_DEP_SAMPL_PLACE foreign key (dsp_seq_no)
      references deponi_sampling_place (dsp_seq_no)
         on delete cascade
go

IF(OBJECT_ID('FK_DEPONI_SAMP_PLACE_BOR_FILTER', 'F') IS NULL)
alter table deponi_sampling_place
   add constraint FK_DEPONI_SAMP_PLACE_BOR_FILTER foreign key (filterid)
      references bor_filter (filterid)
go

IF(OBJECT_ID('FK_DEPONI_SAMP_PLACE_SAMPLING_PLACE', 'F') IS NULL)
alter table deponi_sampling_place
   add constraint FK_DEPONI_SAMP_PLACE_SAMPLING_PLACE foreign key (place_seq_no)
      references sampling_place (place_seq_no)
go

IF(OBJECT_ID('FK_DEPONI_SAMP_PLACE_DEPONI', 'F') IS NULL)
alter table deponi_sampling_place
   add constraint FK_DEPONI_SAMP_PLACE_DEPONI foreign key (deponi_seq_no)
      references deponi (deponi_seq_no)
go

IF(OBJECT_ID('FK_DEPONI_SAMP_PLACE_DEPONI_ANA_PROGRAM', 'F') IS NULL)
alter table deponi_sampling_place_ap
   add constraint FK_DEPONI_SAMP_PLACE_DEPONI_ANA_PROGRAM foreign key (dap_seq_no)
      references deponi_analysis_program (dap_seq_no)
go

IF(OBJECT_ID('FK_DEPONI_SAMP_PLACE_AP_DEPONI_SAMP_PLACE', 'F') IS NULL)
alter table deponi_sampling_place_ap
   add constraint FK_DEPONI_SAMP_PLACE_AP_DEPONI_SAMP_PLACE foreign key (dsp_seq_no)
      references deponi_sampling_place (dsp_seq_no)
go

IF(OBJECT_ID('FK_DEPONI_AP_DEADLINE_DEPONI_SAMP_PLACE', 'F') IS NULL)
alter table deponi_sp_ap_deadline
   add constraint FK_DEPONI_AP_DEADLINE_DEPONI_SAMP_PLACE foreign key (dspa_seq_no)
      references deponi_sampling_place_ap (dspa_seq_no)
go

IF(OBJECT_ID('FK_DEPONI_SUB_UNIT_DEPONI_UNIT', 'F') IS NULL)
alter table deponi_subunit
   add constraint FK_DEPONI_SUB_UNIT_DEPONI_UNIT foreign key (unit_seq_no)
      references deponi_unit (unit_seq_no)
go

IF(OBJECT_ID('FK_DEPONI_UNIT_DEPONI_UNIT_CLASSIFICATION', 'F') IS NULL)
alter table deponi_unit
   add constraint FK_DEPONI_UNIT_DEPONI_UNIT_CLASSIFICATION foreign key (classification)
      references deponi_unit_classification (classification)
go

IF(OBJECT_ID('FK_DEPONI_UNIT_DEPONI', 'F') IS NULL)
alter table deponi_unit
   add constraint FK_DEPONI_UNIT_DEPONI foreign key (deponi_seq_no)
      references deponi (deponi_seq_no)
go

IF(OBJECT_ID('FK_DEPONI_UNIT_LEACHATE_DEPONI_UNIT', 'F') IS NULL)
alter table deponi_unit_leachate
   add constraint FK_DEPONI_UNIT_LEACHATE_DEPONI_UNIT foreign key (unit_seq_no)
      references deponi_unit (unit_seq_no)
go

IF(OBJECT_ID('FK_DEPONI_UNIT_WST_CAP_DEPONI_UNIT', 'F') IS NULL)
alter table deponi_unit_waste_capacity
   add constraint FK_DEPONI_UNIT_WST_CAP_DEPONI_UNIT foreign key (unit_seq_no)
      references deponi_unit (unit_seq_no)
go

IF(OBJECT_ID('FK_DEPONI_X_BOR_DEPONI', 'F') IS NULL)
alter table deponi_x_boring
   add constraint FK_DEPONI_X_BOR_DEPONI foreign key (deponi_seq_no)
      references deponi (deponi_seq_no)
         on delete cascade
go

IF(OBJECT_ID('FK_DEPONI_X_BORING_BOR_BORING', 'F') IS NULL)
alter table deponi_x_boring
   add constraint FK_DEPONI_X_BORING_BOR_BORING foreign key (boring_seq_no)
      references bor_borings (boring_seq_no)
         on delete cascade
go

create table dbo.deponi_unit_note (
   unote_seq_no         numeric(9,0)         not null,
   unit_seq_no          numeric(9,0)         not null,
   comments		varchar(max)         null,
   created              datetime             null default getdate(),
   created_by           varchar(6)           null default user_name(),
   changed              datetime             null,
   changed_by           varchar(6)           null,
   constraint PK_DEPONI_UNIT_NOTE primary key (unote_seq_no)
)
go

grant SELECT,INSERT,DELETE,UPDATE on deponi_unit_note to SYSMGR, DEPONI_USER
go


IF(OBJECT_ID('FK_DEPONI_UNIT_NOTE_DEPONI_UNIT', 'F') IS NULL)
alter table deponi_unit_note
   add constraint FK_DEPONI_UNIT_NOTE_DEPONI_UNIT foreign key (unit_seq_no)
      references deponi_unit (unit_seq_no)
         on delete cascade
go
